@@ -8,13 +8,16 @@ from biomaj_download.download.interface import DownloadInterface
 
 class LocalDownload(DownloadInterface):
     '''
-    Base class to copy file from local system
+    Base class to copy file from local system.
 
     protocol=cp
     server=localhost
     remote.dir=/blast/db/FASTA/
 
     remote.files=^alu.*\\.gz$
+
+    Note that we redefine download and list in such a way that we don't need to
+    define _download and _network_configuration.
     '''
 
     def __init__(self, rootdir, use_hardlinks=False):
@@ -57,7 +60,12 @@ class LocalDownload(DownloadInterface):
         rfiles = []
         rdirs = []
 
-        files = [f for f in os.listdir(self.rootdir + directory)]
+        try:
+            files = [f for f in os.listdir(self.rootdir + directory)]
+        except Exception as e:
+            msg = 'Error while listing ' + self.rootdir + ' - ' + str(e)
+            self.logger.error(msg)
+            raise e
         for file_in_files in files:
             rfile = {}
             fstat = os.stat(os.path.join(self.rootdir + directory, file_in_files))
