@@ -3,6 +3,10 @@ import datetime
 import logging
 import logging.config
 import yaml
+try:
+    from yaml import CLoader as Loader
+except ImportError:
+    from yaml import Loader
 import redis
 import uuid
 import traceback
@@ -85,7 +89,7 @@ class DownloadService(object):
         self.bank = None
         self.download_callback = None
         with open(config_file, 'r') as ymlfile:
-            self.config = yaml.load(ymlfile, Loader=yaml.FullLoader)
+            self.config = yaml.load(ymlfile, Loader=Loader)
             Utils.service_config_override(self.config)
 
         Zipkin.set_config(self.config)
